@@ -81,7 +81,7 @@ def main():
         )
     parser.add_argument(
         'command',
-        choices = ['update', 'build', 'test'],
+        choices = ['update', 'build', 'test', 'historical'],
         help = 'The command you want to run.',
         nargs = 1,
         type = str,
